
package my.servlets;

import java.io.*;
import java.util.logging.Level;
import java.util.logging.Logger;
import javax.ejb.EJB;
import javax.naming.*;
import javax.servlet.*;
import javax.servlet.annotation.WebServlet;
import javax.servlet.http.*;
import my.ejbs.StatefulSessionBeanRemote;
import my.ejbs.StatelessSessionBeanRemote;
import util.HTMLFilter;


@WebServlet(name="Servlet", urlPatterns={"/servlet"})
public class Servlet2EJB
    extends HttpServlet {
    
    private StatefulSessionBeanRemote  sfulSessionBean  = lookupStatefulSessionBeanRemote();
    @EJB(name = "slessSessionBean")
    private StatelessSessionBeanRemote slessSessionBean;// = lookupStatelessSessionBeanRemote();;
    

    @Override
    public void service(HttpServletRequest req, HttpServletResponse resp)
            throws ServletException, IOException {

        resp.setContentType("text/html");
        PrintWriter out = resp.getWriter();

        try {

            out.println("<HTML> <HEAD> <TITLE> Servlet & Stateless/StatefulEJBs</TITLE> </HEAD> <BODY BGCOLOR=white>");
            out.println("<CENTER> <FONT size=+1> Servlet2EJBs: Please enter a message </FONT> </CENTER> <p> ");
            out.println("<form method=\"GET\">");
            out.println("<TABLE>");
            out.println("<tr><td>Message for the stateless EJB: </td>");
            out.println("<td><input type=\"text\" name=\"sl_msg\"> </td>");
            out.println("</tr><tr><td></td>");
            out.println("<td><input type=\"submit\" name=\"sub1\"> </td>");
            out.println("</tr>");
            out.println("</TABLE>");
            out.println("</form>");
            
            out.println("<form method=\"GET\">");
            out.println("<TABLE>");
            out.println("<tr><td>Message for the stateful EJB (per servlet): </td>");
            out.println("<td><input type=\"text\" name=\"sfservlet_msg\"> </td>");
            out.println("</tr><tr><td></td>");
            out.println("<td><input type=\"submit\" name=\"sub2\"> </td>");
            out.println("</tr>");
            out.println("</TABLE>");
            out.println("</form>");
            
            out.println("<form method=\"GET\">");
            out.println("<TABLE>");
            out.println("<tr><td>Message for the stateful EJB (per client): </td>");
            out.println("<td><input type=\"text\" name=\"sfclient_msg\"> </td>");
            out.println("</tr><tr><td></td>");
            out.println("<td><input type=\"submit\" name=\"sub3\"> </td>");
            out.println("</tr>");
            out.println("</TABLE>");
            out.println("</form>");
            
            String val = req.getParameter("sl_msg");  
            if ((val != null) && (val.trim().length() > 0)) {
                out.println("<FONT size=+1 color=red> Message back from StatelessSessionBean: </FONT>"
                            + "<br>"+HTMLFilter.filter(slessSessionBean.bounce(val)) + "<br>");
            }
            else {
                val = req.getParameter("sfservlet_msg");
                if ((val != null) && (val.trim().length() > 0)) {
                    out.println("<FONT size=+1 color=red> Message(s) back from StatefulSessionBean (per servlet): </FONT>"
                                + "<br>"+HTMLFilter.filter(sfulSessionBean.addAndRead(val)).replace("\n", "<br>") + "<br>");
                }
                else {
                    val = req.getParameter("sfclient_msg");
                    if ((val != null) && (val.trim().length() > 0)) {
                        HttpSession session = req.getSession();
                        StatefulSessionBeanRemote sfulPerClient = lookupStatefulSessionBeanRemoteInSession(session);
                        
                        out.println("<FONT size=+1 color=red> Message(s) back from StatefulSessionBean (per client): </FONT>"
                                    + "<br>"+HTMLFilter.filter(sfulPerClient.addAndRead(val)).replace("\n", "<br>") + "<br>");
                    }
                }
            }
            out.println("</BODY> </HTML> ");

        } catch (Exception ex) {
            ex.printStackTrace();
            System.out.println("webclient servlet test failed");
            throw new ServletException(ex);
        }
    }

    
    
    
    private StatefulSessionBeanRemote lookupStatefulSessionBeanRemote() {
        try {
            Context c = new InitialContext();
            return (StatefulSessionBeanRemote) c.lookup("java:global/CDS_08_EJB_ejb/StatefulSessionBean!my.ejbs.StatefulSessionBeanRemote");
            //return (StatefulSessionBeanRemote) c.lookup("java:global/CDS_08_EJB_ejb/StatelessSessionBean");
        } catch (NamingException ne) {
            Logger.getLogger(getClass().getName()).log(Level.SEVERE, "exception caught", ne);
            throw new RuntimeException(ne);
        }
    }
    
    
    
    
    
    private StatefulSessionBeanRemote lookupStatefulSessionBeanRemoteInSession(HttpSession session) {
        StatefulSessionBeanRemote rRef;
        rRef = (StatefulSessionBeanRemote) session.getAttribute("cachedSSBreference");
        if (rRef == null) {
            rRef=lookupStatefulSessionBeanRemote();
            session.setAttribute("cachedSSBreference", rRef);
        }
        return rRef;
    }
    
    
    
    
    private StatelessSessionBeanRemote lookupStatelessSessionBeanRemote() {
        try {
            Context c = new InitialContext();
            return (StatelessSessionBeanRemote) c.lookup("java:global/CDS_08_EJB_ejb/StatelessSessionBean!my.ejbs.StatelessSessionBeanRemote");
            //return (StatelessSessionBeanRemote) c.lookup("java:global/CDS_08_EJB_ejb/StatelessSessionBean");
        } catch (NamingException ne) {
            Logger.getLogger(getClass().getName()).log(Level.SEVERE, "exception caught", ne);
            throw new RuntimeException(ne);
        }
    }


}
